@@ -1,5 +1,7 @@
 from dataclasses import dataclass
 from datetime import datetime
+from enum import Enum
+
 from dateutil import parser
 import functools
 from typing import Any, List, Optional, Dict
@@ -39,7 +41,7 @@ class ApiEndpoint:
 
 
 def deserialize_one(json, dataclass: Optional[Any]):
-    return from_dict(data_class=dataclass, data=json, config=config.Config(type_hooks=TYPE_HOOKS))
+    return from_dict(data_class=dataclass, data=json, config=config.Config(type_hooks=TYPE_HOOKS, cast=[Enum]))
 
 
 def deserialize(json, dataclass: Optional[Any]):
